<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;  
use Illuminate\Support\Facades\Hash; 
use Illuminate\Support\Facades\Auth;

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Style\Fill;
use PhpOffice\PhpSpreadsheet\Style\Font;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Alignment;


use App\Models\Claim;
use App\Models\Client;
use App\Models\Company;
use App\Models\Card;
use App\Models\Policy;
use App\Models\Appliance;

class ClaimController extends Controller
{
    public function index(Request $request)
    {
  
        $claimQuery = Claim::query();



            // Refunds
            if ($request->export == 1) {

                $fileName = 'Claim.xlsx';
                $pre_renewal_data = $claimQuery->get();

                // Create a new Spreadsheet object
                $spreadsheet = new Spreadsheet();
                $sheet = $spreadsheet->getActiveSheet();

                // Define column headers for the detailed report
                $columns = [
                    'Company Name', 'Claim Number','Policy Number', 'Inception Date','Expiry Date','Policy Type','Policy Duration','Description of Claim','Policy Holder Name','Policy Holder Surname','Policy Holder Address - First Line', 'Policy Holder Address - Town','Policy Holder Address - Postcode','Outstanding Amount', 'Amount Paid This Month', 'Total Incurred Amount','Date of Notification','Date of Loss','Claim Settlement Date','Claim Status'
                ];

                // Define summary headers
                $summaryHeaders = [
                    'Facility', 'Coverholder', 'Month', 'Total Incurred'
                ];
 
 
                
                // Calculate summary data dynamically
                $totalPolicies = $pre_renewal_data->count();
                $totalGrossPremiumIpt = $pre_renewal_data->sum('gross_premium_ipt');
                $totalGrossPremiumExclIpt = $pre_renewal_data->sum('gross_premium');
                $averageTaxLevy = $pre_renewal_data->avg('tax');

                // Prepare summary data for insertion
                $summaryData = [
                    $totalPolicies,
                    $totalGrossPremiumIpt,
                    $totalGrossPremiumExclIpt,
                    $averageTaxLevy
                ];



                // Add summary headers with styling
                $summaryHeaderStyle = [
                    'font' => [
                        'bold' => true,
                        'size' => 11,
                        'color' => ['rgb' => '000000'],
                    ],
                    'fill' => [
                        'fillType' => Fill::FILL_SOLID,
                        'color' => ['rgb' => '99cd00']
                    ],
                    'alignment' => [
                        'horizontal' => Alignment::HORIZONTAL_CENTER,
                        'vertical' => Alignment::VERTICAL_CENTER,
                        'wrapText' => true, 
                    ],
                    'borders' => [
                        'allBorders' => [
                            'borderStyle' => Border::BORDER_THIN,
                            'color' => ['rgb' => '000000']
                        ]
                    ]
                ];



                // Add detailed column headers with styling
                $headerStyle = [
                    'font' => [
                        'bold' => true,
                        'size' => 11,
                        'color' => ['rgb' => '000000'],
                    ],
                    'fill' => [
                        'fillType' => Fill::FILL_SOLID,
                        'color' => ['rgb' => '99cd00']
                    ],
                    'alignment' => [
                        'horizontal' => Alignment::HORIZONTAL_CENTER,
                        'vertical' => Alignment::VERTICAL_CENTER,
                        'wrapText' => true,
                    ],
                    'borders' => [
                        'allBorders' => [
                            'borderStyle' => Border::BORDER_THIN,
                            'color' => ['rgb' => '000000']
                        ]
                    ]
                ];

                   

                // Set summary headers
                $sheet->fromArray($summaryHeaders, NULL, 'A1');
                $sheet->getStyle('A1:D1')->applyFromArray($summaryHeaderStyle);


                // Set summary data
                $sheet->fromArray($summaryData, NULL, 'A2');
                $sheet->getStyle('A2:D2')->applyFromArray($summaryHeaderStyle);

                // Leave some rows between summary and detailed headers
                $currentRow = 6; // Row index for the detailed headers

                // Set detailed column headers
                $sheet->fromArray($columns, NULL, 'A' . $currentRow);
                $sheet->getStyle('A' . $currentRow . ':U' . $currentRow)->applyFromArray($headerStyle); 

  

                // Add data rows
                $rowIndex = $currentRow + 1; // Start from row below the headers

                foreach ($pre_renewal_data as $pre_renewal) {
                    $client = clientDetail($pre_renewal->client_id);
                    $policy = policyDetail($pre_renewal->policy_id);   


                    $row = [
                        companyDetail($client->company_id)->name ?? null , 
                        $pre_renewal->claim_no ?? null,
                        $policy->plan_number ?? null,
                        $policy->start_date ?? null,
                        $policy->end_date ?? null,
                        $policy->policy_type ?? null, 
                        Duration($policy->start_date, $policy->end_date) ?? null, 
                        $pre_renewal->description ?? null, 
                        $client->forename ?? null,
                        $client->surname ?? null,
                        $client->address ?? null,
                        $client->city ?? null,
                        $client->postcode ?? null, 
                        $pre_renewal->outstanding_amount ?? null,
                        $pre_renewal->amount_paid_this_month ?? null,
                        $pre_renewal->total_incurred_amount ?? null, 
                        $pre_renewal->created_at ?? null,
                        $pre_renewal->created_at ?? null,
                        $pre_renewal->satlement_date ?? null,
                        $pre_renewal->status ?? null,
 

                    ];

                    $sheet->fromArray($row, NULL, 'A' . $rowIndex++);
                }

                // Create Xlsx writer and save the file
                $writer = new Xlsx($spreadsheet);

                // Create a custom temp directory if needed
                $customTempDir = storage_path('app/temp');
                if (!file_exists($customTempDir)) {
                    mkdir($customTempDir, 0777, true);
                }

                // Generate a unique temporary file name
                $temp_file = tempnam($customTempDir, 'phpxltmp');

                // Error handling for file creation
                if ($temp_file === false) {
                    return response()->json(['error' => 'Failed to create temporary file.'], 500);
                }

                // Save the file
                try {
                    $writer->save($temp_file);
                } catch (\Exception $e) {
                    return response()->json(['error' => 'Failed to save the Excel file: ' . $e->getMessage()], 500);
                }

                // Return the response as an Excel file
                return response()->download($temp_file, $fileName)->deleteFileAfterSend(true);
            }
 
             
 

        $claims = Claim::paginate(10);
        return view('admin.claim.allclaim',compact("claims")); 
    }

 
 
    public function create()
    { 
        $clients = Client::all(); 
        $policies = Policy::all();  
        return view('admin.claim.new',compact("clients","policies"));    
    }
 
    public function store(Request $request)
    {
        
        // dd($request->all());
        // dd("working");

        $message = [
            'client_id.required' => 'The Client id field is required.', 
            'policy_id.required' => 'The Policy id field is required.',   
            'description.required' => 'The Discription is required.', 
            'outstanding_amount.required' => 'The Outstanding Amount field is required.', 
            'amount_paid_this_month.required' => 'The Amount Paid This Month field is required.',
            'total_incurred_amount.required' => 'The Total Incurred Amount is required.', 
            'satlement_date.required' => 'The Satlement Date is required.', 
             
        ];

        $validatedData = $request->validate([ 
           'client_id' => 'required',
           'policy_id' => 'required',
           'description' => 'required|string|max:255', 
           'outstanding_amount' => 'required',
           'amount_paid_this_month' => 'required',
           'total_incurred_amount' => 'required|numeric',
           'satlement_date' => 'required',
            
        ], $message);


        $prefix = "CLAIM";
        $timestamp = date('ymdHis'); // Year (yy), Month (mm), Day (dd), Hour (HH), Minute (MM), Second (SS)
        $randomNumber = mt_rand(10000, 99999); // Generate a random number between 10000 and 99999

         $claim_number = $prefix . $timestamp . $randomNumber;


        // dd($request->all());

        $Claim = new Claim();

        $Claim->client_id = $request->client_id;
        $Claim->policy_id = $request->policy_id;
        $Claim->claim_no = $claim_number;
        $Claim->description = $request->description;
        $Claim->outstanding_amount = $request->outstanding_amount;
        $Claim->amount_paid_this_month = $request->amount_paid_this_month;
        $Claim->total_incurred_amount = $request->total_incurred_amount; 
        $Claim->notification_date = $request->notification_date;
        $Claim->date_of_loss = $request->date_of_loss;
        $Claim->satlement_date = $request->satlement_date;
        $Claim->status = "1";  
        $Claim->save(); 
 

        return redirect()->route('admin.claims');
    }


    public function edit($id)
    {
        // dd('test');
         $clients = Client::all(); 
        $policies = Policy::all(); 
        $claim = Claim::find($id); 
        return view('admin.claim.edit',compact('claim','clients','policies'));
    }

 
    public function view($id)
    { 
        $client = Policy::find($id); 
        $cards = Card::where('client_id',$id)->get(); 
         return view('admin.claim.view',compact('client','cards'));
    }
 
    public function update(Request $request, $id)
    {
        $message = [
            'client_id.required' => 'The Client id field is required.', 
            'policy_id.required' => 'The Policy id field is required.',   
            'description.required' => 'The Discription is required.', 
            'outstanding_amount.required' => 'The Outstanding Amount field is required.', 
            'amount_paid_this_month.required' => 'The Amount Paid This Month field is required.',
            'total_incurred_amount.required' => 'The Total Incurred Amount is required.', 
            'satlement_date.required' => 'The Satlement Date is required.', 
             
        ];

        $validatedData = $request->validate([ 
           'client_id' => 'required',
           'policy_id' => 'required',
           'description' => 'required|string|max:255', 
           'outstanding_amount' => 'required',
           'amount_paid_this_month' => 'required',
           'total_incurred_amount' => 'required|numeric',
           'satlement_date' => 'required',
            
        ], $message);



        // dd($request->all());

        $Claim = Claim::find($id);

        $Claim->client_id = $request->client_id;
        $Claim->policy_id = $request->policy_id;
        $Claim->description = $request->description;
        $Claim->outstanding_amount = $request->outstanding_amount;
        $Claim->amount_paid_this_month = $request->amount_paid_this_month;
        $Claim->total_incurred_amount = $request->total_incurred_amount; 
        $Claim->notification_date = $request->notification_date;
        $Claim->date_of_loss = $request->date_of_loss;
        $Claim->satlement_date = $request->satlement_date;
        $Claim->status = 1;  
        $Claim->update(); 

        return redirect()->route('admin.claims');
    }

   
 
    public function destroy($id)
    { 
        $Claim = Claim::find($id);
        $Claim->delete();
        return redirect()->route('admin.claims');

    }
}
