@extends('admin.layouts.adminmaster')

@section('title', 'Edit Claim')

@section('content') 

    
<div class="mb-5">
    <div class="card">
        <div class="card-body">

            <form id="policyForm" enctype="multipart/form-data" action="{{ route('admin.claim_update', $claim->id) }}" method="post">
                @csrf

                    <div class="row">  
                    <div class="col-12 mb-3">
                        <label class="form-label" for="client_id">Client Name</label>
                        <div class="position-relative">
                            <select name="client_id" id="client_id" class="select2-single" data-placeholder="Select Client">
                                <option></option>
                                @foreach($clients as $key => $client)
                                <option value="{{ $client->id }}"  @if ( $client->id == $claim->client_id) {{ 'selected' }} @endif>{{ $client->forename }}</option>
                                @endforeach
                            </select>
                            <div class="text-danger error-message" id="client_id_error"></div>
                        </div>
                    </div>

                     <div class="col-12 mb-3">
                        <label class="form-label" for="policy_id">Policy Name</label>
                        <div class="position-relative">
                            <select name="policy_id" id="policy_id" class="select2-single" data-placeholder="Select Policy">
                                <option></option>
                                @foreach($policies as $key => $policy)
                                <option value="{{ $policy->id }}"  @if ( $policy->id == $claim->policy_id) {{ 'selected' }} @endif>{{ $policy->plan_number }}</option>
                                @endforeach
                            </select>
                            <div class="text-danger error-message" id="policy_id_error"></div>
                        </div>
                    </div>

                    


                     <div class="col-lg-12 mb-3">
                        <label class="form-label" for="description">Description</label>
                        <div class="position-relative">
                            <textarea class="form-control" id="description" name="description" rows="4">{{$claim->description}}</textarea>
                            <div class="text-danger error-message" id="description_error"></div>
                        </div>
                    </div>
 

                     <div class="col-lg-6 mb-3">
                        <label class="form-label" for="satlement_date">Satlement Date</label>
                        <div class="position-relative">
                            <input type="text" class="form-control flatpicker-startdate" value="{{$claim->satlement_date}}" id="satlement_date" name="satlement_date" placeholder="Enter Satlement Date (YYYY-MM-DD)" />
                            <div class="text-danger error-message" id="satlement_date_error"></div>
                        </div>
                    </div>
                        
                     <div class="col-lg-6 mb-3">
                        <label class="form-label" for="outstanding_amount">Outstanding Amount</label>
                        <div class="position-relative">
                            <input type="number" class="form-control" value="{{$claim->outstanding_amount}}" id="outstanding_amount" name="outstanding_amount" placeholder="Enter Outstanding Amount" />
                            <div class="text-danger error-message" id="outstanding_amount_error"></div>
                        </div>
                    </div>


                     <div class="col-lg-6 mb-3">
                        <label class="form-label" for="amount_paid_this_month">Amount Paid This Month</label>
                        <div class="position-relative">
                            <input type="number" class="form-control" value="{{$claim->amount_paid_this_month}}" id="amount_paid_this_month" name="amount_paid_this_month" placeholder="Enter Amount Paid This Month" />
                            <div class="text-danger error-message" id="amount_paid_this_month_error"></div>
                        </div>
                    </div>


                     <div class="col-lg-6 mb-3">
                        <label class="form-label" for="total_incurred_amount">Total Incurred Amount</label>
                        <div class="position-relative">
                            <input type="number" class="form-control" value="{{$claim->total_incurred_amount}}" id="total_incurred_amount" name="total_incurred_amount" placeholder="Enter Total Incurred Amount" />
                            <div class="text-danger error-message" id="total_incurred_amount_error"></div>
                        </div>
                    </div>

  
                    <div class="col-12">
                        <button class="btn btn-primary" type="submit">Update</button>
                    </div>
                </div>
            </form>
        </div>
    </div>
</div>

@endsection

@section('specificscripts')
 
 <!-- apply validation only -->
<script>
document.addEventListener('DOMContentLoaded', function() {
    const form = document.getElementById('policyForm');

    form.addEventListener('submit', function(event) {
        let isValid = true;

        // Clear previous errors
        document.querySelectorAll('.error-message').forEach(el => el.textContent = '');

           // Get form fields
        const client_id = document.getElementById('client_id');
        const policy_id = document.getElementById('policy_id');
        const description = document.getElementById('description'); 
        const outstanding_amount = document.getElementById('outstanding_amount');
        const amount_paid_this_month = document.getElementById('amount_paid_this_month');
        const total_incurred_amount = document.getElementById('total_incurred_amount');
        const satlement_date = document.getElementById('satlement_date');


        // Validate each field
        

        if (client_id.value.trim() === '') {
            isValid = false;
            document.getElementById('client_id_error').textContent = 'Client Id is required.';
        }
         if (policy_id.value.trim() === '') {
            isValid = false;
            document.getElementById('policy_id_error').textContent = 'Policy Id is required.';
        }

        
        if (description.value.trim() === '') {
            isValid = false;
            document.getElementById('description_error').textContent = 'Description is required.';
        }
 

        if (satlement_date.value.trim() === '') {
            isValid = false;
            document.getElementById('satlement_date_error').textContent = 'Sattlement Date is required.';
        }

      
 

        if (outstanding_amount.value.trim() === '' || isNaN(outstanding_amount.value)) {
            isValid = false;
            document.getElementById('outstanding_amount_error').textContent = 'Outstanding Amount is required and must be a number.';
        }


        if (amount_paid_this_month.value.trim() === '' || isNaN(amount_paid_this_month.value)) {
            isValid = false;
            document.getElementById('amount_paid_this_month_error').textContent = 'Amount Paid This Month is required and must be a number.';
        }

         if (total_incurred_amount.value.trim() === '' || isNaN(total_incurred_amount.value)) {
            isValid = false;
            document.getElementById('total_incurred_amount_error').textContent = 'Total Incurred Amount is required and must be a number.';
        }
   

        if (!isValid) {
            event.preventDefault(); // Prevent form submission if invalid
        }
    });
});




  $(".flatpicker-enddate").flatpickr({
        dateFormat: "Y-m-d",
        // maxDate: "today"
    });

      $(".flatpicker-startdate").flatpickr({
        dateFormat: "Y-m-d",
        // maxDate: "today"
    });

</script>
 

@stop
